@@ -13,6 +13,7 @@
  * @since 3.7.0
  * @since 4.6.0 Moved to its own file from wp-admin/includes/class-wp-upgrader.php.
  */
+#[AllowDynamicProperties]
 class WP_Automatic_Updater {
 
 	/**
@@ -23,7 +24,7 @@ class WP_Automatic_Updater {
 	protected $update_results = array();
 
 	/**
-	 * Whether the entire automatic updater is disabled.
+	 * Determines whether the entire automatic updater is disabled.
 	 *
 	 * @since 3.7.0
 	 */
@@ -56,7 +57,7 @@ class WP_Automatic_Updater {
 	}
 
 	/**
-	 * Check for version control checkouts.
+	 * Checks for version control checkouts.
 	 *
 	 * Checks for Subversion, Git, Mercurial, and Bazaar. It recursively looks up the
 	 * filesystem to the top of the drive, erring on the side of detecting a VCS
@@ -151,7 +152,9 @@ class WP_Automatic_Updater {
 		}
 
 		// If we can't do an auto core update, we may still be able to email the user.
-		if ( ! $skin->request_filesystem_credentials( false, $context, $allow_relaxed_file_ownership ) || $this->is_vcs_checkout( $context ) ) {
+		if ( ! $skin->request_filesystem_credentials( false, $context, $allow_relaxed_file_ownership )
+			|| $this->is_vcs_checkout( $context )
+		) {
 			if ( 'core' === $type ) {
 				$this->send_core_update_notification_email( $item );
 			}
@@ -182,16 +185,19 @@ class WP_Automatic_Updater {
 		 * Filters whether to automatically update core, a plugin, a theme, or a language.
 		 *
 		 * The dynamic portion of the hook name, `$type`, refers to the type of update
-		 * being checked. Potential hook names include:
+		 * being checked.
+		 *
+		 * Possible hook names include:
 		 *
 		 *  - `auto_update_core`
 		 *  - `auto_update_plugin`
 		 *  - `auto_update_theme`
 		 *  - `auto_update_translation`
 		 *
-		 * Generally speaking, plugins, themes, and major core versions are not updated
-		 * by default, while translations and minor and development versions for core
-		 * are updated by default.
+		 * Since WordPress 3.7, minor and development versions of core, and translations have
+		 * been auto-updated by default. New installs on WordPress 5.6 or higher will also
+		 * auto-update major versions by default. Starting in 5.6, older sites can opt-in to
+		 * major version auto-updates, and auto-updates for plugins and themes.
 		 *
 		 * See the {@see 'allow_dev_auto_core_updates'}, {@see 'allow_minor_auto_core_updates'},
 		 * and {@see 'allow_major_auto_core_updates'} filters for a more straightforward way to
@@ -217,7 +223,7 @@ class WP_Automatic_Updater {
 		if ( 'core' === $type ) {
 			global $wpdb;
 
-			$php_compat = version_compare( phpversion(), $item->php_version, '>=' );
+			$php_compat = version_compare( PHP_VERSION, $item->php_version, '>=' );
 			if ( file_exists( WP_CONTENT_DIR . '/db.php' ) && empty( $wpdb->is_mysql ) ) {
 				$mysql_compat = true;
 			} else {
@@ -231,7 +237,7 @@ class WP_Automatic_Updater {
 
 		// If updating a plugin or theme, ensure the minimum PHP version requirements are satisfied.
 		if ( in_array( $type, array( 'plugin', 'theme' ), true ) ) {
-			if ( ! empty( $item->requires_php ) && version_compare( phpversion(), $item->requires_php, '<' ) ) {
+			if ( ! empty( $item->requires_php ) && version_compare( PHP_VERSION, $item->requires_php, '<' ) ) {
 				return false;
 			}
 		}
@@ -252,7 +258,10 @@ class WP_Automatic_Updater {
 		$notified = get_site_option( 'auto_core_update_notified' );
 
 		// Don't notify if we've already notified the same email address of the same version.
-		if ( $notified && get_site_option( 'admin_email' ) === $notified['email'] && $notified['version'] == $item->current ) {
+		if ( $notified
+			&& get_site_option( 'admin_email' ) === $notified['email']
+			&& $notified['version'] === $item->current
+		) {
 			return false;
 		}
 
@@ -287,7 +296,7 @@ class WP_Automatic_Updater {
 	}
 
 	/**
-	 * Update an item, if appropriate.
+	 * Updates an item, if appropriate.
 	 *
 	 * @since 3.7.0
 	 *
@@ -411,9 +420,10 @@ class WP_Automatic_Updater {
 				return false;
 			}
 
-			// Core doesn't output this, so let's append it so we don't get confused.
+			// Core doesn't output this, so let's append it, so we don't get confused.
 			if ( is_wp_error( $upgrade_result ) ) {
-				$skin->error( __( 'Installation failed.' ), $upgrade_result );
+				$upgrade_result->add( 'installation_failed', __( 'Installation failed.' ) );
+				$skin->error( $upgrade_result );
 			} else {
 				$skin->feedback( __( 'WordPress updated successfully.' ) );
 			}
@@ -622,9 +632,14 @@ class WP_Automatic_Updater {
 			$send = false;
 		}
 
-		$n = get_site_option( 'auto_core_update_notified' );
+		$notified = get_site_option( 'auto_core_update_notified' );
+
 		// Don't notify if we've already notified the same email address of the same version of the same notification type.
-		if ( $n && 'fail' === $n['type'] && get_site_option( 'admin_email' ) === $n['email'] && $n['version'] == $core_update->current ) {
+		if ( $notified
+			&& 'fail' === $notified['type']
+			&& get_site_option( 'admin_email' ) === $notified['email']
+			&& $notified['version'] === $core_update->current
+		) {
 			$send = false;
 		}
 
@@ -672,7 +687,13 @@ class WP_Automatic_Updater {
 			$next_user_core_update = $core_update;
 		}
 
-		$newer_version_available = ( 'upgrade' === $next_user_core_update->response && version_compare( $next_user_core_update->version, $core_update->version, '>' ) );
+		if ( 'upgrade' === $next_user_core_update->response
+			&& version_compare( $next_user_core_update->version, $core_update->version, '>' )
+		) {
+			$newer_version_available = true;
+		} else {
+			$newer_version_available = false;
+		}
 
 		/**
 		 * Filters whether to send an email following an automatic background core update.
@@ -758,7 +779,7 @@ class WP_Automatic_Updater {
 				// Don't show this message if there is a newer version available.
 				// Potential for confusion, and also not useful for them to know at this point.
 				if ( 'fail' === $type && ! $newer_version_available ) {
-					$body .= __( 'We tried but were unable to update your site automatically.' ) . ' ';
+					$body .= __( 'An attempt was made, but your site could not be updated automatically.' ) . ' ';
 				}
 
 				$body .= __( 'Updating is easy and only takes a few moments:' );
@@ -809,7 +830,7 @@ class WP_Automatic_Updater {
 		}
 
 		if ( $critical_support ) {
-			$body .= ' ' . __( "If you reach out to us, we'll also ensure you'll never have this problem again." );
+			$body .= ' ' . __( "Reach out to WordPress Core developers to ensure you'll never have this problem again." );
 		}
 
 		// If things are successful and we're now on the latest, mention plugins and themes if any are out of date.
@@ -824,7 +845,7 @@ class WP_Automatic_Updater {
 			$body .= "\n***\n\n";
 			/* translators: %s: WordPress version. */
 			$body .= sprintf( __( 'Your site was running version %s.' ), get_bloginfo( 'version' ) );
-			$body .= ' ' . __( 'We have some data that describes the error your site encountered.' );
+			$body .= ' ' . __( 'Some data that describes the error your site encountered has been put together.' );
 			$body .= ' ' . __( 'Your hosting company, support forum volunteers, or a friendly developer may be able to use this information to help you:' );
 
 			// If we had a rollback and we're still critical, then the rollback failed too.
@@ -1080,23 +1101,34 @@ class WP_Automatic_Updater {
 				$body[] = __( 'These plugins failed to update:' );
 
 				foreach ( $failed_updates['plugin'] as $item ) {
+					$body_message = '';
+					$item_url     = '';
+
+					if ( ! empty( $item->item->url ) ) {
+						$item_url = ' : ' . esc_url( $item->item->url );
+					}
+
 					if ( $item->item->current_version ) {
-						$body[] = sprintf(
-							/* translators: 1: Plugin name, 2: Current version number, 3: New version number. */
-							__( '- %1$s (from version %2$s to %3$s)' ),
+						$body_message .= sprintf(
+							/* translators: 1: Plugin name, 2: Current version number, 3: New version number, 4: Plugin URL. */
+							__( '- %1$s (from version %2$s to %3$s)%4$s' ),
 							$item->name,
 							$item->item->current_version,
-							$item->item->new_version
+							$item->item->new_version,
+							$item_url
 						);
 					} else {
-						$body[] = sprintf(
-							/* translators: 1: Plugin name, 2: Version number. */
-							__( '- %1$s version %2$s' ),
+						$body_message .= sprintf(
+							/* translators: 1: Plugin name, 2: Version number, 3: Plugin URL. */
+							__( '- %1$s version %2$s%3$s' ),
 							$item->name,
-							$item->item->new_version
+							$item->item->new_version,
+							$item_url
 						);
 					}
 
+					$body[] = $body_message;
+
 					$past_failure_emails[ $item->item->plugin ] = $item->item->new_version;
 				}
 
@@ -1141,22 +1173,32 @@ class WP_Automatic_Updater {
 				$body[] = __( 'These plugins are now up to date:' );
 
 				foreach ( $successful_updates['plugin'] as $item ) {
+					$body_message = '';
+					$item_url     = '';
+
+					if ( ! empty( $item->item->url ) ) {
+						$item_url = ' : ' . esc_url( $item->item->url );
+					}
+
 					if ( $item->item->current_version ) {
-						$body[] = sprintf(
-							/* translators: 1: Plugin name, 2: Current version number, 3: New version number. */
-							__( '- %1$s (from version %2$s to %3$s)' ),
+						$body_message .= sprintf(
+							/* translators: 1: Plugin name, 2: Current version number, 3: New version number, 4: Plugin URL. */
+							__( '- %1$s (from version %2$s to %3$s)%4$s' ),
 							$item->name,
 							$item->item->current_version,
-							$item->item->new_version
+							$item->item->new_version,
+							$item_url
 						);
 					} else {
-						$body[] = sprintf(
-							/* translators: 1: Plugin name, 2: Version number. */
-							__( '- %1$s version %2$s' ),
+						$body_message .= sprintf(
+							/* translators: 1: Plugin name, 2: Version number, 3: Plugin URL. */
+							__( '- %1$s version %2$s%3$s' ),
 							$item->name,
-							$item->item->new_version
+							$item->item->new_version,
+							$item_url
 						);
 					}
+					$body[] = $body_message;
 
 					unset( $past_failure_emails[ $item->item->plugin ] );
 				}
@@ -1179,7 +1221,7 @@ class WP_Automatic_Updater {
 						);
 					} else {
 						$body[] = sprintf(
-							 /* translators: 1: Theme name, 2: Version number. */
+							/* translators: 1: Theme name, 2: Version number. */
 							__( '- %1$s version %2$s' ),
 							$item->name,
 							$item->item->new_version
@@ -1216,9 +1258,15 @@ class WP_Automatic_Updater {
 		$body[] = __( 'https://wordpress.org/support/forums/' );
 		$body[] = "\n" . __( 'The WordPress Team' );
 
+		if ( '' !== get_option( 'blogname' ) ) {
+			$site_title = wp_specialchars_decode( get_option( 'blogname' ), ENT_QUOTES );
+		} else {
+			$site_title = parse_url( home_url(), PHP_URL_HOST );
+		}
+
 		$body    = implode( "\n", $body );
 		$to      = get_site_option( 'admin_email' );
-		$subject = sprintf( $subject, wp_specialchars_decode( get_option( 'blogname' ), ENT_QUOTES ) );
+		$subject = sprintf( $subject, $site_title );
 		$headers = '';
 
 		$email = compact( 'to', 'subject', 'body', 'headers' );
@@ -1270,6 +1318,7 @@ class WP_Automatic_Updater {
 		// Core.
 		if ( isset( $this->update_results['core'] ) ) {
 			$result = $this->update_results['core'][0];
+
 			if ( $result->result && ! is_wp_error( $result->result ) ) {
 				/* translators: %s: WordPress version. */
 				$body[] = sprintf( __( 'SUCCESS: WordPress was successfully updated to %s' ), $result->name );
@@ -1278,6 +1327,7 @@ class WP_Automatic_Updater {
 				$body[] = sprintf( __( 'FAILED: WordPress failed to update to %s' ), $result->name );
 				$failures++;
 			}
+
 			$body[] = '';
 		}
 
@@ -1286,7 +1336,9 @@ class WP_Automatic_Updater {
 			if ( ! isset( $this->update_results[ $type ] ) ) {
 				continue;
 			}
+
 			$success_items = wp_list_filter( $this->update_results[ $type ], array( 'result' => true ) );
+
 			if ( $success_items ) {
 				$messages = array(
 					'plugin'      => __( 'The following plugins were successfully updated:' ),
@@ -1300,7 +1352,8 @@ class WP_Automatic_Updater {
 					$body[] = ' * ' . sprintf( __( 'SUCCESS: %s' ), $name );
 				}
 			}
-			if ( $success_items != $this->update_results[ $type ] ) {
+
+			if ( $success_items !== $this->update_results[ $type ] ) {
 				// Failed updates.
 				$messages = array(
 					'plugin'      => __( 'The following plugins failed to update:' ),
@@ -1309,6 +1362,7 @@ class WP_Automatic_Updater {
 				);
 
 				$body[] = $messages[ $type ];
+
 				foreach ( $this->update_results[ $type ] as $item ) {
 					if ( ! $item->result || is_wp_error( $item->result ) ) {
 						/* translators: %s: Name of plugin / theme / translation. */
@@ -1317,10 +1371,16 @@ class WP_Automatic_Updater {
 					}
 				}
 			}
+
 			$body[] = '';
 		}
 
-		$site_title = wp_specialchars_decode( get_bloginfo( 'name' ), ENT_QUOTES );
+		if ( '' !== get_bloginfo( 'name' ) ) {
+			$site_title = wp_specialchars_decode( get_bloginfo( 'name' ), ENT_QUOTES );
+		} else {
+			$site_title = parse_url( home_url(), PHP_URL_HOST );
+		}
+
 		if ( $failures ) {
 			$body[] = trim(
 				__(
@@ -1357,18 +1417,23 @@ Thanks! -- The WordPress Team"
 			if ( ! isset( $this->update_results[ $type ] ) ) {
 				continue;
 			}
+
 			foreach ( $this->update_results[ $type ] as $update ) {
 				$body[] = $update->name;
 				$body[] = str_repeat( '-', strlen( $update->name ) );
+
 				foreach ( $update->messages as $message ) {
 					$body[] = '  ' . html_entity_decode( str_replace( '&#8230;', '...', $message ) );
 				}
+
 				if ( is_wp_error( $update->result ) ) {
 					$results = array( 'update' => $update->result );
+
 					// If we rolled back, we want to know an error that occurred then too.
 					if ( 'rollback_was_required' === $update->result->get_error_code() ) {
 						$results = (array) $update->result->get_error_data();
 					}
+
 					foreach ( $results as $result_type => $result ) {
 						if ( ! is_wp_error( $result ) ) {
 							continue;
@@ -1387,6 +1452,7 @@ Thanks! -- The WordPress Team"
 						}
 					}
 				}
+
 				$body[] = '';
 			}
 		}
