@@ -31,27 +31,27 @@ define( 'WXR_VERSION', '1.2' );
  * @param array $args {
  *     Optional. Arguments for generating the WXR export file for download. Default empty array.
  *
- *     @type string $content        Type of content to export. If set, only the post content of this post type
- *                                  will be exported. Accepts 'all', 'post', 'page', 'attachment', or a defined
- *                                  custom post. If an invalid custom post type is supplied, every post type for
- *                                  which `can_export` is enabled will be exported instead. If a valid custom post
- *                                  type is supplied but `can_export` is disabled, then 'posts' will be exported
- *                                  instead. When 'all' is supplied, only post types with `can_export` enabled will
- *                                  be exported. Default 'all'.
- *     @type string $author         Author to export content for. Only used when `$content` is 'post', 'page', or
- *                                  'attachment'. Accepts false (all) or a specific author ID. Default false (all).
- *     @type string $category       Category (slug) to export content for. Used only when `$content` is 'post'. If
- *                                  set, only post content assigned to `$category` will be exported. Accepts false
- *                                  or a specific category slug. Default is false (all categories).
- *     @type string $start_date     Start date to export content from. Expected date format is 'Y-m-d'. Used only
- *                                  when `$content` is 'post', 'page' or 'attachment'. Default false (since the
- *                                  beginning of time).
- *     @type string $end_date       End date to export content to. Expected date format is 'Y-m-d'. Used only when
- *                                  `$content` is 'post', 'page' or 'attachment'. Default false (latest publish date).
- *     @type string $status         Post status to export posts for. Used only when `$content` is 'post' or 'page'.
- *                                  Accepts false (all statuses except 'auto-draft'), or a specific status, i.e.
- *                                  'publish', 'pending', 'draft', 'auto-draft', 'future', 'private', 'inherit', or
- *                                  'trash'. Default false (all statuses except 'auto-draft').
+ *     @type string $content    Type of content to export. If set, only the post content of this post type
+ *                              will be exported. Accepts 'all', 'post', 'page', 'attachment', or a defined
+ *                              custom post. If an invalid custom post type is supplied, every post type for
+ *                              which `can_export` is enabled will be exported instead. If a valid custom post
+ *                              type is supplied but `can_export` is disabled, then 'posts' will be exported
+ *                              instead. When 'all' is supplied, only post types with `can_export` enabled will
+ *                              be exported. Default 'all'.
+ *     @type string $author     Author to export content for. Only used when `$content` is 'post', 'page', or
+ *                              'attachment'. Accepts false (all) or a specific author ID. Default false (all).
+ *     @type string $category   Category (slug) to export content for. Used only when `$content` is 'post'. If
+ *                              set, only post content assigned to `$category` will be exported. Accepts false
+ *                              or a specific category slug. Default is false (all categories).
+ *     @type string $start_date Start date to export content from. Expected date format is 'Y-m-d'. Used only
+ *                              when `$content` is 'post', 'page' or 'attachment'. Default false (since the
+ *                              beginning of time).
+ *     @type string $end_date   End date to export content to. Expected date format is 'Y-m-d'. Used only when
+ *                              `$content` is 'post', 'page' or 'attachment'. Default false (latest publish date).
+ *     @type string $status     Post status to export posts for. Used only when `$content` is 'post' or 'page'.
+ *                              Accepts false (all statuses except 'auto-draft'), or a specific status, i.e.
+ *                              'publish', 'pending', 'draft', 'auto-draft', 'future', 'private', 'inherit', or
+ *                              'trash'. Default false (all statuses except 'auto-draft').
  * }
  */
 function export_wp( $args = array() ) {
@@ -169,7 +169,7 @@ function export_wp( $args = array() ) {
 
 		// Put categories in order with no child going before its parent.
 		while ( $cat = array_shift( $categories ) ) {
-			if ( 0 == $cat->parent || isset( $cats[ $cat->parent ] ) ) {
+			if ( ! $cat->parent || isset( $cats[ $cat->parent ] ) ) {
 				$cats[ $cat->term_id ] = $cat;
 			} else {
 				$categories[] = $cat;
@@ -178,7 +178,7 @@ function export_wp( $args = array() ) {
 
 		// Put terms in order with no child going before its parent.
 		while ( $t = array_shift( $custom_terms ) ) {
-			if ( 0 == $t->parent || isset( $terms[ $t->parent ] ) ) {
+			if ( ! $t->parent || isset( $terms[ $t->parent ] ) ) {
 				$terms[ $t->term_id ] = $t;
 			} else {
 				$custom_terms[] = $t;
@@ -189,7 +189,7 @@ function export_wp( $args = array() ) {
 	}
 
 	/**
-	 * Wrap given string in XML CDATA tag.
+	 * Wraps given string in XML CDATA tag.
 	 *
 	 * @since 2.1.0
 	 *
@@ -207,7 +207,7 @@ function export_wp( $args = array() ) {
 	}
 
 	/**
-	 * Return the URL of the site
+	 * Returns the URL of the site.
 	 *
 	 * @since 2.5.0
 	 *
@@ -224,11 +224,11 @@ function export_wp( $args = array() ) {
 	}
 
 	/**
-	 * Output a cat_name XML tag from a given category object
+	 * Outputs a cat_name XML tag from a given category object.
 	 *
 	 * @since 2.1.0
 	 *
-	 * @param WP_Term $category Category Object
+	 * @param WP_Term $category Category Object.
 	 */
 	function wxr_cat_name( $category ) {
 		if ( empty( $category->name ) ) {
@@ -239,11 +239,11 @@ function export_wp( $args = array() ) {
 	}
 
 	/**
-	 * Output a category_description XML tag from a given category object
+	 * Outputs a category_description XML tag from a given category object.
 	 *
 	 * @since 2.1.0
 	 *
-	 * @param WP_Term $category Category Object
+	 * @param WP_Term $category Category Object.
 	 */
 	function wxr_category_description( $category ) {
 		if ( empty( $category->description ) ) {
@@ -254,11 +254,11 @@ function export_wp( $args = array() ) {
 	}
 
 	/**
-	 * Output a tag_name XML tag from a given tag object
+	 * Outputs a tag_name XML tag from a given tag object.
 	 *
 	 * @since 2.3.0
 	 *
-	 * @param WP_Term $tag Tag Object
+	 * @param WP_Term $tag Tag Object.
 	 */
 	function wxr_tag_name( $tag ) {
 		if ( empty( $tag->name ) ) {
@@ -269,11 +269,11 @@ function export_wp( $args = array() ) {
 	}
 
 	/**
-	 * Output a tag_description XML tag from a given tag object
+	 * Outputs a tag_description XML tag from a given tag object.
 	 *
 	 * @since 2.3.0
 	 *
-	 * @param WP_Term $tag Tag Object
+	 * @param WP_Term $tag Tag Object.
 	 */
 	function wxr_tag_description( $tag ) {
 		if ( empty( $tag->description ) ) {
@@ -284,11 +284,11 @@ function export_wp( $args = array() ) {
 	}
 
 	/**
-	 * Output a term_name XML tag from a given term object
+	 * Outputs a term_name XML tag from a given term object.
 	 *
 	 * @since 2.9.0
 	 *
-	 * @param WP_Term $term Term Object
+	 * @param WP_Term $term Term Object.
 	 */
 	function wxr_term_name( $term ) {
 		if ( empty( $term->name ) ) {
@@ -299,11 +299,11 @@ function export_wp( $args = array() ) {
 	}
 
 	/**
-	 * Output a term_description XML tag from a given term object
+	 * Outputs a term_description XML tag from a given term object.
 	 *
 	 * @since 2.9.0
 	 *
-	 * @param WP_Term $term Term Object
+	 * @param WP_Term $term Term Object.
 	 */
 	function wxr_term_description( $term ) {
 		if ( empty( $term->description ) ) {
@@ -314,7 +314,7 @@ function export_wp( $args = array() ) {
 	}
 
 	/**
-	 * Output term meta XML tags for a given term object.
+	 * Outputs term meta XML tags for a given term object.
 	 *
 	 * @since 4.6.0
 	 *
@@ -345,7 +345,7 @@ function export_wp( $args = array() ) {
 	}
 
 	/**
-	 * Output list of authors with posts
+	 * Outputs list of authors with posts.
 	 *
 	 * @since 3.1.0
 	 *
@@ -384,7 +384,7 @@ function export_wp( $args = array() ) {
 	}
 
 	/**
-	 * Output all navigation menu terms
+	 * Outputs all navigation menu terms.
 	 *
 	 * @since 3.1.0
 	 */
@@ -405,7 +405,7 @@ function export_wp( $args = array() ) {
 	}
 
 	/**
-	 * Output list of taxonomy terms, in XML tag format, associated with a post
+	 * Outputs list of taxonomy terms, in XML tag format, associated with a post.
 	 *
 	 * @since 2.3.0
 	 */
@@ -424,8 +424,12 @@ function export_wp( $args = array() ) {
 	}
 
 	/**
-	 * @param bool   $return_me
-	 * @param string $meta_key
+	 * Determines whether to selectively skip post meta used for WXR exports.
+	 *
+	 * @since 3.3.0
+	 *
+	 * @param bool   $return_me Whether to skip the current post meta. Default false.
+	 * @param string $meta_key  Meta key.
 	 * @return bool
 	 */
 	function wxr_filter_postmeta( $return_me, $meta_key ) {
@@ -632,7 +636,7 @@ function export_wp( $args = array() ) {
 			<wp:comment_id><?php echo (int) $c->comment_ID; ?></wp:comment_id>
 			<wp:comment_author><?php echo wxr_cdata( $c->comment_author ); ?></wp:comment_author>
 			<wp:comment_author_email><?php echo wxr_cdata( $c->comment_author_email ); ?></wp:comment_author_email>
-			<wp:comment_author_url><?php echo esc_url_raw( $c->comment_author_url ); ?></wp:comment_author_url>
+			<wp:comment_author_url><?php echo sanitize_url( $c->comment_author_url ); ?></wp:comment_author_url>
 			<wp:comment_author_IP><?php echo wxr_cdata( $c->comment_author_IP ); ?></wp:comment_author_IP>
 			<wp:comment_date><?php echo wxr_cdata( $c->comment_date ); ?></wp:comment_date>
 			<wp:comment_date_gmt><?php echo wxr_cdata( $c->comment_date_gmt ); ?></wp:comment_date_gmt>
