@@ -31,7 +31,7 @@
  */
 
 /**
- * Container for storing shortcode tags and their hook to call for the shortcode
+ * Container for storing shortcode tags and their hook to call for the shortcode.
  *
  * @since 2.5.0
  *
@@ -64,15 +64,25 @@ function add_shortcode( $tag, $callback ) {
 	global $shortcode_tags;
 
 	if ( '' === trim( $tag ) ) {
-		$message = __( 'Invalid shortcode name: Empty name given.' );
-		_doing_it_wrong( __FUNCTION__, $message, '4.4.0' );
+		_doing_it_wrong(
+			__FUNCTION__,
+			__( 'Invalid shortcode name: Empty name given.' ),
+			'4.4.0'
+		);
 		return;
 	}
 
 	if ( 0 !== preg_match( '@[<>&/\[\]\x00-\x20=]@', $tag ) ) {
-		/* translators: 1: Shortcode name, 2: Space-separated list of reserved characters. */
-		$message = sprintf( __( 'Invalid shortcode name: %1$s. Do not use spaces or reserved characters: %2$s' ), $tag, '& / < > [ ] =' );
-		_doing_it_wrong( __FUNCTION__, $message, '4.4.0' );
+		_doing_it_wrong(
+			__FUNCTION__,
+			sprintf(
+				/* translators: 1: Shortcode name, 2: Space-separated list of reserved characters. */
+				__( 'Invalid shortcode name: %1$s. Do not use spaces or reserved characters: %2$s' ),
+				$tag,
+				'& / < > [ ] ='
+			),
+			'4.4.0'
+		);
 		return;
 	}
 
@@ -95,11 +105,10 @@ function remove_shortcode( $tag ) {
 }
 
 /**
- * Clear all shortcodes.
+ * Clears all shortcodes.
  *
- * This function is simple, it clears all of the shortcode tags by replacing the
- * shortcodes global by a empty array. This is actually a very efficient method
- * for removing all shortcodes.
+ * This function clears all of the shortcode tags by replacing the shortcodes global with
+ * an empty array. This is actually an efficient method for removing all shortcodes.
  *
  * @since 2.5.0
  *
@@ -112,7 +121,7 @@ function remove_all_shortcodes() {
 }
 
 /**
- * Whether a registered shortcode exists named $tag
+ * Determines whether a registered shortcode exists named $tag.
  *
  * @since 3.6.0
  *
@@ -127,7 +136,7 @@ function shortcode_exists( $tag ) {
 }
 
 /**
- * Whether the passed content contains the specified shortcode
+ * Determines whether the passed content contains the specified shortcode.
  *
  * @since 3.6.0
  *
@@ -216,7 +225,7 @@ function apply_shortcodes( $content, $ignore_html = false ) {
 }
 
 /**
- * Search content for shortcodes and filter shortcodes through their hooks.
+ * Searches content for shortcodes and filter shortcodes through their hooks.
  *
  * If there are no shortcode tags defined, then the content will be returned
  * without any filtering. This might cause issues when plugins are disabled but
@@ -262,7 +271,7 @@ function do_shortcode( $content, $ignore_html = false ) {
 }
 
 /**
- * Retrieve the shortcode regular expression for searching.
+ * Retrieves the shortcode regular expression for searching.
  *
  * The regular expression combines the shortcode tags in the regular expression
  * in a regex class.
@@ -352,9 +361,12 @@ function do_shortcode_tag( $m ) {
 	$attr = shortcode_parse_atts( $m[3] );
 
 	if ( ! is_callable( $shortcode_tags[ $tag ] ) ) {
-		/* translators: %s: Shortcode tag. */
-		$message = sprintf( __( 'Attempting to parse a shortcode without a valid callback: %s' ), $tag );
-		_doing_it_wrong( __FUNCTION__, $message, '4.3.0' );
+		_doing_it_wrong(
+			__FUNCTION__,
+			/* translators: %s: Shortcode tag. */
+			sprintf( __( 'Attempting to parse a shortcode without a valid callback: %s' ), $tag ),
+			'4.3.0'
+		);
 		return $m[0];
 	}
 
@@ -366,10 +378,10 @@ function do_shortcode_tag( $m ) {
 	 *
 	 * @since 4.7.0
 	 *
-	 * @param false|string $return      Short-circuit return value. Either false or the value to replace the shortcode with.
-	 * @param string       $tag         Shortcode name.
-	 * @param array|string $attr        Shortcode attributes array or empty string.
-	 * @param array        $m           Regular expression match array.
+	 * @param false|string $return Short-circuit return value. Either false or the value to replace the shortcode with.
+	 * @param string       $tag    Shortcode name.
+	 * @param array|string $attr   Shortcode attributes array or empty string.
+	 * @param array        $m      Regular expression match array.
 	 */
 	$return = apply_filters( 'pre_do_shortcode_tag', false, $tag, $attr, $m );
 	if ( false !== $return ) {
@@ -394,7 +406,7 @@ function do_shortcode_tag( $m ) {
 }
 
 /**
- * Search only inside HTML elements for shortcodes and process them.
+ * Searches only inside HTML elements for shortcodes and process them.
  *
  * Any [ or ] characters remaining inside elements will be HTML encoded
  * to prevent interference with shortcodes that are outside the elements.
@@ -508,7 +520,7 @@ function do_shortcodes_in_html_tags( $content, $ignore_html, $tagnames ) {
 }
 
 /**
- * Remove placeholders added by do_shortcodes_in_html_tags().
+ * Removes placeholders added by do_shortcodes_in_html_tags().
  *
  * @since 4.2.3
  *
@@ -528,18 +540,18 @@ function unescape_invalid_shortcodes( $content ) {
 }
 
 /**
- * Retrieve the shortcode attributes regex.
+ * Retrieves the shortcode attributes regex.
  *
  * @since 4.4.0
  *
- * @return string The shortcode attribute regular expression
+ * @return string The shortcode attribute regular expression.
  */
 function get_shortcode_atts_regex() {
 	return '/([\w-]+)\s*=\s*"([^"]*)"(?:\s|$)|([\w-]+)\s*=\s*\'([^\']*)\'(?:\s|$)|([\w-]+)\s*=\s*([^\s\'"]+)(?:\s|$)|"([^"]*)"(?:\s|$)|\'([^\']*)\'(?:\s|$)|(\S+)(?:\s|$)/';
 }
 
 /**
- * Retrieve all attributes from the shortcodes tag.
+ * Retrieves all attributes from the shortcodes tag.
  *
  * The attributes list has the attribute name as the key and the value of the
  * attribute as the value in the key/value pair. This allows for easier
@@ -590,7 +602,7 @@ function shortcode_parse_atts( $text ) {
 }
 
 /**
- * Combine user attributes with known attributes and fill in defaults when needed.
+ * Combines user attributes with known attributes and fill in defaults when needed.
  *
  * The pairs should be considered to be all of the attributes which are
  * supported by the caller and given as a list. The returned attributes will
@@ -639,7 +651,7 @@ function shortcode_atts( $pairs, $atts, $shortcode = '' ) {
 }
 
 /**
- * Remove all shortcode tags from the given content.
+ * Removes all shortcode tags from the given content.
  *
  * @since 2.5.0
  *
