@@ -7,7 +7,7 @@
  */
 
 /**
- * Retrieve path to a template
+ * Retrieves path to a template.
  *
  * Used to quickly retrieve the path of a template without including the file
  * extension. It will also check the parent theme, if the file exists, with
@@ -16,8 +16,8 @@
  *
  * @since 1.5.0
  *
- * @param string $type      Filename without extension.
- * @param array  $templates An optional list of template candidates
+ * @param string   $type      Filename without extension.
+ * @param string[] $templates An optional list of template candidates.
  * @return string Full path to template file.
  */
 function get_query_template( $type, $templates = array() ) {
@@ -30,19 +30,41 @@ function get_query_template( $type, $templates = array() ) {
 	/**
 	 * Filters the list of template filenames that are searched for when retrieving a template to use.
 	 *
+	 * The dynamic portion of the hook name, `$type`, refers to the filename -- minus the file
+	 * extension and any non-alphanumeric characters delimiting words -- of the file to load.
 	 * The last element in the array should always be the fallback template for this query type.
 	 *
-	 * Possible values for `$type` include: 'index', '404', 'archive', 'author', 'category', 'tag', 'taxonomy', 'date',
-	 * 'embed', 'home', 'frontpage', 'privacypolicy', 'page', 'paged', 'search', 'single', 'singular', and 'attachment'.
+	 * Possible hook names include:
+	 *
+	 *  - `404_template_hierarchy`
+	 *  - `archive_template_hierarchy`
+	 *  - `attachment_template_hierarchy`
+	 *  - `author_template_hierarchy`
+	 *  - `category_template_hierarchy`
+	 *  - `date_template_hierarchy`
+	 *  - `embed_template_hierarchy`
+	 *  - `frontpage_template_hierarchy`
+	 *  - `home_template_hierarchy`
+	 *  - `index_template_hierarchy`
+	 *  - `page_template_hierarchy`
+	 *  - `paged_template_hierarchy`
+	 *  - `privacypolicy_template_hierarchy`
+	 *  - `search_template_hierarchy`
+	 *  - `single_template_hierarchy`
+	 *  - `singular_template_hierarchy`
+	 *  - `tag_template_hierarchy`
+	 *  - `taxonomy_template_hierarchy`
 	 *
 	 * @since 4.7.0
 	 *
-	 * @param array $templates A list of template candidates, in descending order of priority.
+	 * @param string[] $templates A list of template candidates, in descending order of priority.
 	 */
 	$templates = apply_filters( "{$type}_template_hierarchy", $templates );
 
 	$template = locate_template( $templates );
 
+	$template = locate_block_template( $template, $type, $templates );
+
 	/**
 	 * Filters the path of the queried template by type.
 	 *
@@ -50,21 +72,39 @@ function get_query_template( $type, $templates = array() ) {
 	 * extension and any non-alphanumeric characters delimiting words -- of the file to load.
 	 * This hook also applies to various types of files loaded as part of the Template Hierarchy.
 	 *
-	 * Possible values for `$type` include: 'index', '404', 'archive', 'author', 'category', 'tag', 'taxonomy', 'date',
-	 * 'embed', 'home', 'frontpage', 'privacypolicy', 'page', 'paged', 'search', 'single', 'singular', and 'attachment'.
+	 * Possible hook names include:
+	 *
+	 *  - `404_template`
+	 *  - `archive_template`
+	 *  - `attachment_template`
+	 *  - `author_template`
+	 *  - `category_template`
+	 *  - `date_template`
+	 *  - `embed_template`
+	 *  - `frontpage_template`
+	 *  - `home_template`
+	 *  - `index_template`
+	 *  - `page_template`
+	 *  - `paged_template`
+	 *  - `privacypolicy_template`
+	 *  - `search_template`
+	 *  - `single_template`
+	 *  - `singular_template`
+	 *  - `tag_template`
+	 *  - `taxonomy_template`
 	 *
 	 * @since 1.5.0
 	 * @since 4.8.0 The `$type` and `$templates` parameters were added.
 	 *
-	 * @param string $template  Path to the template. See locate_template().
-	 * @param string $type      Sanitized filename without extension.
-	 * @param array  $templates A list of template candidates, in descending order of priority.
+	 * @param string   $template  Path to the template. See locate_template().
+	 * @param string   $type      Sanitized filename without extension.
+	 * @param string[] $templates A list of template candidates, in descending order of priority.
 	 */
 	return apply_filters( "{$type}_template", $template, $type, $templates );
 }
 
 /**
- * Retrieve path of index template in current or parent template.
+ * Retrieves path of index template in current or parent template.
  *
  * The template hierarchy and template path are filterable via the {@see '$type_template_hierarchy'}
  * and {@see '$type_template'} dynamic hooks, where `$type` is 'index'.
@@ -80,7 +120,7 @@ function get_index_template() {
 }
 
 /**
- * Retrieve path of 404 template in current or parent template.
+ * Retrieves path of 404 template in current or parent template.
  *
  * The template hierarchy and template path are filterable via the {@see '$type_template_hierarchy'}
  * and {@see '$type_template'} dynamic hooks, where `$type` is '404'.
@@ -96,7 +136,7 @@ function get_404_template() {
 }
 
 /**
- * Retrieve path of archive template in current or parent template.
+ * Retrieves path of archive template in current or parent template.
  *
  * The template hierarchy and template path are filterable via the {@see '$type_template_hierarchy'}
  * and {@see '$type_template'} dynamic hooks, where `$type` is 'archive'.
@@ -122,7 +162,7 @@ function get_archive_template() {
 }
 
 /**
- * Retrieve path of post type archive template in current or parent template.
+ * Retrieves path of post type archive template in current or parent template.
  *
  * The template hierarchy and template path are filterable via the {@see '$type_template_hierarchy'}
  * and {@see '$type_template'} dynamic hooks, where `$type` is 'archive'.
@@ -148,7 +188,7 @@ function get_post_type_archive_template() {
 }
 
 /**
- * Retrieve path of author template in current or parent template.
+ * Retrieves path of author template in current or parent template.
  *
  * The hierarchy for this template looks like:
  *
@@ -186,7 +226,7 @@ function get_author_template() {
 }
 
 /**
- * Retrieve path of category template in current or parent template.
+ * Retrieves path of category template in current or parent template.
  *
  * The hierarchy for this template looks like:
  *
@@ -232,7 +272,7 @@ function get_category_template() {
 }
 
 /**
- * Retrieve path of tag template in current or parent template.
+ * Retrieves path of tag template in current or parent template.
  *
  * The hierarchy for this template looks like:
  *
@@ -278,7 +318,7 @@ function get_tag_template() {
 }
 
 /**
- * Retrieve path of custom taxonomy term template in current or parent template.
+ * Retrieves path of custom taxonomy term template in current or parent template.
  *
  * The hierarchy for this template looks like:
  *
@@ -325,7 +365,7 @@ function get_taxonomy_template() {
 }
 
 /**
- * Retrieve path of date template in current or parent template.
+ * Retrieves path of date template in current or parent template.
  *
  * The template hierarchy and template path are filterable via the {@see '$type_template_hierarchy'}
  * and {@see '$type_template'} dynamic hooks, where `$type` is 'date'.
@@ -341,7 +381,7 @@ function get_date_template() {
 }
 
 /**
- * Retrieve path of home template in current or parent template.
+ * Retrieves path of home template in current or parent template.
  *
  * The template hierarchy and template path are filterable via the {@see '$type_template_hierarchy'}
  * and {@see '$type_template'} dynamic hooks, where `$type` is 'home'.
@@ -359,7 +399,7 @@ function get_home_template() {
 }
 
 /**
- * Retrieve path of front page template in current or parent template.
+ * Retrieves path of front page template in current or parent template.
  *
  * The template hierarchy and template path are filterable via the {@see '$type_template_hierarchy'}
  * and {@see '$type_template'} dynamic hooks, where `$type` is 'frontpage'.
@@ -377,7 +417,7 @@ function get_front_page_template() {
 }
 
 /**
- * Retrieve path of Privacy Policy page template in current or parent template.
+ * Retrieves path of Privacy Policy page template in current or parent template.
  *
  * The template hierarchy and template path are filterable via the {@see '$type_template_hierarchy'}
  * and {@see '$type_template'} dynamic hooks, where `$type` is 'privacypolicy'.
@@ -395,7 +435,9 @@ function get_privacy_policy_template() {
 }
 
 /**
- * Retrieve path of page template in current or parent template.
+ * Retrieves path of page template in current or parent template.
+ *
+ * Note: For block themes, use locate_block_template function instead.
  *
  * The hierarchy for this template looks like:
  *
@@ -456,7 +498,7 @@ function get_page_template() {
 }
 
 /**
- * Retrieve path of search template in current or parent template.
+ * Retrieves path of search template in current or parent template.
  *
  * The template hierarchy and template path are filterable via the {@see '$type_template_hierarchy'}
  * and {@see '$type_template'} dynamic hooks, where `$type` is 'search'.
@@ -472,7 +514,7 @@ function get_search_template() {
 }
 
 /**
- * Retrieve path of single template in current or parent template. Applies to single Posts,
+ * Retrieves path of single template in current or parent template. Applies to single Posts,
  * single Attachments, and single custom post types.
  *
  * The hierarchy for this template looks like:
@@ -586,7 +628,7 @@ function get_singular_template() {
 }
 
 /**
- * Retrieve path of attachment template in current or parent template.
+ * Retrieves path of attachment template in current or parent template.
  *
  * The hierarchy for this template looks like:
  *
@@ -638,7 +680,7 @@ function get_attachment_template() {
 }
 
 /**
- * Retrieve the name of the highest priority template file that exists.
+ * Retrieves the name of the highest priority template file that exists.
  *
  * Searches in the STYLESHEETPATH before TEMPLATEPATH and wp-includes/theme-compat
  * so that themes which inherit from a parent theme can just overload one file.
@@ -680,7 +722,7 @@ function locate_template( $template_names, $load = false, $require_once = true,
 }
 
 /**
- * Require the template file with WordPress environment.
+ * Requires the template file with WordPress environment.
  *
  * The globals are set up for the template file to ensure that the WordPress
  * environment is available from within the function. The query variables are
@@ -726,9 +768,31 @@ function load_template( $_template_file, $require_once = true, $args = array() )
 		$s = esc_attr( $s );
 	}
 
+	/**
+	 * Fires before a template file is loaded.
+	 *
+	 * @since 6.1.0
+	 *
+	 * @param string $_template_file The full path to the template file.
+	 * @param bool   $require_once   Whether to require_once or require.
+	 * @param array  $args           Additional arguments passed to the template.
+	 */
+	do_action( 'wp_before_load_template', $_template_file, $require_once, $args );
+
 	if ( $require_once ) {
 		require_once $_template_file;
 	} else {
 		require $_template_file;
 	}
+
+	/**
+	 * Fires after a template file is loaded.
+	 *
+	 * @since 6.1.0
+	 *
+	 * @param string $_template_file The full path to the template file.
+	 * @param bool   $require_once   Whether to require_once or require.
+	 * @param array  $args           Additional arguments passed to the template.
+	 */
+	do_action( 'wp_after_load_template', $_template_file, $require_once, $args );
 }
